@@ -1,28 +1,16 @@
 /******************************************************************************
- * main.c 
+ * main.c
  *
  * pdfresurrect - PDF history extraction tool
+ * https://github.com/enferex/pdfresurrect
  *
- * Copyright (C) 2008-2010, 2012, 2017, 2019-21 Matt Davis (enferex).
+ * See https://github.com/enferex/pdfresurrect/blob/master/LICENSE for license
+ * information.
+ * SPDX-License-Identifier: BSD-3-Clause
  *
  * Special thanks to all of the contributors:  See AUTHORS.
- *
  * Special thanks to 757labs (757 crew), they are a great group
  * of people to hack on projects and brainstorm with.
- *
- * main.c is part of pdfresurrect.
- * pdfresurrect is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * pdfresurrect is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with pdfresurrect.  If not, see <http://www.gnu.org/licenses/>.
  *****************************************************************************/
 
 #include <stdio.h>
@@ -37,16 +25,6 @@
 
 static void usage(void)
 {
-    printf(EXEC_NAME " Copyright (C) 2008-2010, 2012, 2013, 2017, 2019-21 "
-           "Matt Davis (enferex)\n"
-           "Special thanks to all contributors and the 757 crew.\n"
-           "See the AUTHORS file for a list of other contributors.\n"
-           "This program comes with ABSOLUTELY NO WARRANTY\n"
-           "This is free software, and you are welcome to redistribute it\n"
-           "under certain conditions.  For details see the file 'LICENSE'\n"
-           "that came with this software or visit:\n"
-           "<http://www.gnu.org/licenses/gpl-3.0.txt>\n\n");
-    
     printf("-- " EXEC_NAME " v" VER" --\n"
            "Usage: ./" EXEC_NAME " <file.pdf> [-i] [-w] [-q]\n"
            "\t -i Display PDF creator information\n"
@@ -54,7 +32,6 @@ static void usage(void)
            "\t -q Display only the number of versions contained in the PDF\n");
 // Experimental feature:
 //           "\t -s Scrub the previous history data from the specified PDF\n");
-
     exit(0);
 }
 
@@ -68,7 +45,7 @@ static void write_version(
     long  start;
     char *c, *new_fname, data;
     FILE *new_fp;
-    
+
     start = ftell(fp);
 
     /* Create file */
@@ -85,13 +62,13 @@ static void write_version(
         free(new_fname);
         return;
     }
-    
+
     /* Copy original PDF */
     fseek(fp, 0, SEEK_SET);
     while (fread(&data, 1, 1, fp))
       fwrite(&data, 1, 1, new_fp);
 
-    /* Emit an older startxref, refering to an older version. */
+    /* Emit an older startxref, referring to an older version. */
     fprintf(new_fp, "\r\nstartxref\r\n%ld\r\n%%%%EOF", xref->start);
 
     /* Clean */
@@ -143,14 +120,14 @@ static void scrub_document(FILE *fp, const pdf_t *pdf)
     /* Copy */
     fseek(fp, SEEK_SET, 0);
     while ((ch = fgetc(fp)) != EOF)
-      fputc(ch, new_fp); 
+      fputc(ch, new_fp);
 
-    /* Find last version (dont zero these baddies) */
+    /* Find last version (don't zero these baddies) */
     last_version = 0;
     for (i=0; i<pdf->n_xrefs; i++)
       if (pdf->xrefs[i].version)
         last_version = pdf->xrefs[i].version;
-   
+
     /* Zero mod objects from all but the most recent version
      * Zero del objects from all versions
      */
@@ -197,7 +174,7 @@ static void display_creator(FILE *fp, const pdf_t *pdf)
     {
         if (!pdf->xrefs[i].version)
           continue;
-      
+
         if (pdf_display_creator(pdf, i))
           printf("\n");
     }
@@ -334,8 +311,8 @@ int main(int argc, char **argv)
             pdf_delete(pdf);
             return -1;
         }
-    
-        /* Write the pdf as a pervious version */
+
+        /* Write the pdf as a previous version */
         for (i=0; i<pdf->n_xrefs; i++)
           if (pdf->xrefs[i].version)
             write_version(fp, name, dname, &pdf->xrefs[i]);
